@@ -10,6 +10,6 @@ ROUTER.register(r'modes', views.ModeView)
 ROUTER.register(r'satellites', views.SatelliteView)
 ROUTER.register(r'transmitters', views.TransmitterView)
 ROUTER.register(r'telemetry', views.TelemetryView)
-ROUTER.register(r'tle', views.TleView)
+ROUTER.register(r'tle', views.LatestTleSetView)
 
 API_URLPATTERNS = ROUTER.urls
